@@ -1,11 +1,11 @@
-from datetime import datetime
+from django.utils.timezone import now as tznow
 
 from django.db import models
 
 class QA(models.Model):
     question = models.CharField(max_length=255)
     answer = models.TextField()
-    last_modified = models.DateTimeField(default=datetime.now, editable=False)
+    last_modified = models.DateTimeField(default=tznow, editable=False)
 
     class Meta:
         db_table = 'nano_faq_qa'
@@ -14,5 +14,5 @@ class QA(models.Model):
         return self.question
 
     def save(self, *args, **kwargs):
-        self.last_modified = datetime.now()
+        self.last_modified = tznow()
         super(QA, self).save(*args, **kwargs)
